@@ -274,7 +274,7 @@ sub createlogactionchain( $$ ) {
 	$chain = substr( $chain, 0, 27 ), redo CHECKDUP if ( $actionref->{actchain} || 0 ) >= 10 and length $chain == 28;
     }
 
-    $logactionchains{"$action:$level"} = $chainref = new_chain 'filter', '%' . $chain . $actionref->{actchain}++;
+    $logactionchains{"$action:$level"} = $chainref = new_standard_chain '%' . $chain . $actionref->{actchain}++;
 
     fatal_error "Too many invocations of Action $action" if $actionref->{actchain} > 99;
     
@@ -302,7 +302,7 @@ sub createlogactionchain( $$ ) {
 
 sub createsimpleactionchain( $ ) {
     my $action  = shift;
-    my $chainref = new_chain 'filter', $action;
+    my $chainref = new_standard_chain $action;
 
     $logactionchains{"$action:none"} = $chainref;
 
@@ -389,7 +389,7 @@ sub process_macro1 ( $$ ) {
     push_open( $macrofile );
 
     while ( read_a_line ) {
-	my ( $mtarget, $msource,  $mdest,  $mproto,  $mports,  $msports, $ mrate, $muser ) = split_line 1, 8, 'macro file';
+	my ( $mtarget, $msource,  $mdest,  $mproto,  $mports,  $msports, $mrate, $muser ) = split_line 1, 8, 'macro file';
 
 	$mtarget =~ s/:.*$//;
 
