@@ -110,6 +110,7 @@ our %EXPORT_TAGS = (
 				       do_test
 				       do_ratelimit
 				       do_user
+				       do_length
 				       do_tos
 				       match_source_dev
 				       match_dest_dev
@@ -421,7 +422,7 @@ sub add_rule($$;$)
     if ( $expandports && $rule =~  '^(.* --dports\s+)([^ ]+)(.*)$' ) {
 	my ($first, $ports, $rest) = ( $1, $2, $3 );
 
-	if ( ( $ports =~ tr/:,/:,/ ) > 15 ) {
+	if ( ( $ports =~ tr/:,/:,/ ) > 14 ) {
 	    my @ports = split '([,:])', $ports;
 
 	    while ( @ports ) {
@@ -1211,6 +1212,16 @@ sub do_tos( $ ) {
     $tos ne '-' ? "-m tos --tos $tos " : '';
 }
 
+#
+# Create a "-m length" match for the passed TOS
+#
+sub do_length( $ ) {
+    my $length = $_[0];
+
+    require_capability( 'LENGTH_MATCH' , 'A non-empty LENGTH' , 's' );
+    $length ne '-' ? "-m length --length $length " : '';
+}
+
 #
 # Match Source Interface
 #
@@ -1345,7 +1356,7 @@ sub match_orig_dest ( $ ) {
     if ( $net =~ /^!/ ) {
 	$net =~ s/!//;
 	validate_net $net, 1;
-	"-m conntrack --ctorigdst ! $net ";
+	$capabilities{NEW_CONNTRACK_MATCH} ? "-m conntrack ! --ctorigdst $net " : "-m conntrack --ctorigdst ! $net ";
     } else {
 	validate_net $net, 1;
 	$net eq ALLIPv4 ? '' : "-m conntrack --ctorigdst $net ";
