@@ -1002,6 +1002,11 @@ sub process_rule1 ( $$$$$$$$$$$ ) {
 	fatal_error "Missing DEST Qualifier ($dest)" if $2 eq '';
 	$destzone = $1;
 	$dest = $2;
+    } elsif ( $dest =~ /.*\..*\./ ) {
+	#
+	# Appears to be an address
+	#
+	$destzone = '-';
     } else {
 	$destzone = $dest;
 	$dest = ALLIPv4;
@@ -1602,6 +1607,8 @@ sub generate_matrix() {
 				if $hostref->{options}{broadcast};
 			}
 
+			clearrule;
+
 			next if $hostref->{options}{destonly}; 
 
 			my $source = match_source_net $net;
