@@ -243,6 +243,8 @@ sub determine_zones()
 {
     my @z;
 
+    my $ipv4 = 0;
+
     my $fn = open_file 'zones';
 
     first_entry "$doing $fn...";
@@ -273,6 +275,7 @@ sub determine_zones()
 
 	if ( $type =~ /ipv4/i ) {
 	    $type = 'ipv4';
+	    $ipv4 = 1;
 	} elsif ( $type =~ /^ipsec4?$/i ) {
 	    $type = 'ipsec4';
 	} elsif ( $type =~ /^bport4?$/i ) {
@@ -287,6 +290,7 @@ sub determine_zones()
 	    $type = "firewall";
 	} elsif ( $type eq '-' ) {
 	    $type = 'ipv4';
+	    $ipv4 = 1;
 	} else {
 	    fatal_error "Invalid zone type ($type)" ;
 	}
@@ -311,6 +315,7 @@ sub determine_zones()
     }
 
     fatal_error "No firewall zone defined" unless $firewall_zone;
+    fatal_error "No IPv4 zones defined" unless $ipv4;
 
     my %ordered;
 
@@ -330,6 +335,7 @@ sub determine_zones()
     }
 
     fatal_error "Internal error in determine_zones()" unless scalar @zones == scalar @z;
+
 }
 
 #
@@ -483,7 +489,7 @@ sub add_group_to_zone($$$$$)
 	if ( substr( $host, 0, 1 ) eq '+' ) {
 	    fatal_error "Invalid ipset name ($host)" unless $host =~ /^\+[a-zA-Z]\w*$/;
 	} else {
-	    validate_host $host;
+	    validate_host $host, 1;
 	}
 
 	push @$new, $switched ? "$interface:$host" : $host;
@@ -513,7 +519,7 @@ sub find_zone( $ ) {
 
     my $zoneref = $zones{$zone};
 
-    fatal_error "Unknown zone" unless $zoneref;
+    fatal_error "Unknown zone ($zone)" unless $zoneref;
 
     $zoneref;
 }
@@ -592,7 +598,7 @@ sub validate_interfaces_file( $ )
 	    $first_entry = 0;
 	}
 
-	my ($zone, $interface, $networks, $options ) = split_line 2, 4, 'interfaces file';
+	my ($zone, $originalinterface, $networks, $options ) = split_line 2, 4, 'interfaces file';
 	my $zoneref;
 	my $bridge = '';
 
@@ -608,16 +614,16 @@ sub validate_interfaces_file( $ )
 	$networks = '' if $networks eq '-';
 	$options  = '' if $options  eq '-';
 
-	( $interface, my ($port, $extra) ) = split /:/ , $interface, 3;
+	my ($interface, $port, $extra) = split /:/ , $originalinterface, 3;
 
-	fatal_error "Invalid INTERFACE" if defined $extra || ! $interface;
+	fatal_error "Invalid INTERFACE ($originalinterface)" if defined $extra || ! $interface;
 
 	fatal_error "Invalid Interface Name ($interface)" if $interface eq '+';
 
 	if ( defined $port ) {
 	    fatal_error qq("Virtual" interfaces are not supported -- see http://www.shorewall.net/Shorewall_and_Aliased_Interfaces.html) if $port =~ /^\d+$/;
 	    require_capability( 'PHYSDEV_MATCH', 'Bridge Ports', '');
-	    require_capability( 'KLUDGEFREE', 'Bridge Ports', '');
+	    fatal_error "Your iptables is not recent enough to support bridge ports" unless $capabilities{KLUDGEFREE};
 	    fatal_error "Duplicate Interface ($port)" if $interfaces{$port};
 	    fatal_error "$interface is not a defined bridge" unless $interfaces{$interface} && $interfaces{$interface}{options}{bridge};
 	    fatal_error "Bridge Ports may only be associated with 'bport' zones" if $zone && $zoneref->{type} ne 'bport4';
@@ -757,6 +763,10 @@ sub validate_interfaces_file( $ )
 
 	push @interfaces, $interface unless $interfaceref->{options}{port};
     }
+    #
+    # Be sure that we have at least one interface
+    #
+    fatal_error "No network interfaces defined" unless @interfaces;
 }
 
 #
@@ -878,6 +888,7 @@ sub validate_hosts_file()
 			tcpflags => 1,
 			broadcast => 1,
 			destonly => 1,
+			sourceonly => 1,
 			);
 
     my $ipsec = 0;
